@@ -15,7 +15,7 @@ source activate testenv
 
 echo "Creating Bintray package..."
 
-# Compile OSQP 
+# Compile OSQP
 cd ${TRAVIS_BUILD_DIR}
 rm -rf build
 mkdir build
@@ -31,27 +31,27 @@ else
     OS_NAME="linux"
     OS_SHARED_LIB_EXT="so"
 fi
-OSQP_DEPLOY_DIR=osqp-0.3.1-${OS_NAME}64
+OSQP_DEPLOY_DIR=osqp-0.4.0-${OS_NAME}64
 mkdir $OSQP_DEPLOY_DIR/
 mkdir $OSQP_DEPLOY_DIR/lib
 mkdir $OSQP_DEPLOY_DIR/include
-# Copy license 
+# Copy license
 cp ../../LICENSE $OSQP_DEPLOY_DIR/
 # Copy includes
 cp ../../include/*.h  $OSQP_DEPLOY_DIR/include
 # Copy static library
-cp libosqpstatic.a $OSQP_DEPLOY_DIR/lib 
+cp libosqp.a $OSQP_DEPLOY_DIR/lib
 # Copy shared library
-cp libosqp.$OS_SHARED_LIB_EXT $OSQP_DEPLOY_DIR/lib 
+cp libosqp.$OS_SHARED_LIB_EXT $OSQP_DEPLOY_DIR/lib
 # Compress package
 tar -czvf $OSQP_DEPLOY_DIR.tar.gz  $OSQP_DEPLOY_DIR
 
 
 # Deploy package
-curl -T $OSQP_DEPLOY_DIR.tar.gz -ubstellato:$BINTRAY_API_KEY -H "X-Bintray-Package:OSQP" -H "X-Bintray-Version:0.3.1" https://api.bintray.com/content/bstellato/generic/OSQP/0.3.1/
+curl -T $OSQP_DEPLOY_DIR.tar.gz -ubstellato:$BINTRAY_API_KEY -H "X-Bintray-Package:OSQP" -H "X-Bintray-Version:0.4.0" https://api.bintray.com/content/bstellato/generic/OSQP/0.4.0/
 
 # Publish
-curl -X POST -ubstellato:$BINTRAY_API_KEY https://api.bintray.com/content/bstellato/generic/OSQP/0.3.1/publish
+curl -X POST -ubstellato:$BINTRAY_API_KEY https://api.bintray.com/content/bstellato/generic/OSQP/0.4.0/publish
 
 
 exit 0
