@@ -7,14 +7,17 @@
 
 #include "minunit.h"
 #include "osqp.h"
+#include "osqp_tester.h"
 
 // Include tests
 #include "lin_alg/test_lin_alg.h"
 #include "solve_linsys/test_solve_linsys.h"
 #include "basic_qp/test_basic_qp.h"
 #include "basic_qp2/test_basic_qp2.h"
-#include "primal_infeasibility/test_primal_infeasibility.h"
+#include "non_cvx/test_non_cvx.h"
 #include "primal_dual_infeasibility/test_primal_dual_infeasibility.h"
+#include "primal_infeasibility/test_primal_infeasibility.h"
+#include "unconstrained/test_unconstrained.h"
 #include "update_matrices/test_update_matrices.h"
 
 
@@ -26,8 +29,10 @@ static char* all_tests() {
   mu_run_test(test_solve_linsys);
   mu_run_test(test_basic_qp);
   mu_run_test(test_basic_qp2);
+  mu_run_test(test_non_cvx);
   mu_run_test(test_primal_infeasibility);
   mu_run_test(test_primal_dual_infeasibility);
+  mu_run_test(test_unconstrained);
   mu_run_test(test_update_matrices);
   return 0;
 }
